/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tySequence__7Ph69cTgZS9be09cTzR9afiJeA tySequence__7Ph69cTgZS9be09cTzR9afiJeA;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_Con__9bOyOsCU76VZVizp72T2TsQ tyObject_Con__9bOyOsCU76VZVizp72T2TsQ;
typedef struct tySequence__z8L8BvgPZ9bdGD1gr7FvhEw tySequence__z8L8BvgPZ9bdGD1gr7FvhEw;
typedef struct tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ;
typedef struct tySequence__AO6tQ23B9aS9b43hhtsROhdQ tySequence__AO6tQ23B9aS9b43hhtsROhdQ;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyTuple__HQcnEvwXwW8nB4mw1aSc9bg tyTuple__HQcnEvwXwW8nB4mw1aSc9bg;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct NimStringDesc NimStringDesc;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
struct TGenericSeq {
NI len;
NI reserved;
};
typedef NU8 tyEnum_InstrKind__82Too4YSWL3lxgkmNlM6Mw;
struct tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w {
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyEnum_InstrKind__82Too4YSWL3lxgkmNlM6Mw kind;
union{
NI dest;
};
};
struct tyObject_Con__9bOyOsCU76VZVizp72T2TsQ {
tySequence__7Ph69cTgZS9be09cTzR9afiJeA* code;
NI inTryStmt;
tySequence__z8L8BvgPZ9bdGD1gr7FvhEw* blocks;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
};
struct tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ {
NIM_BOOL isTryBlock;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* label;
tySequence__AO6tQ23B9aS9b43hhtsROhdQ* breakFixups;
} _isTryBlock_1;
struct {tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* finale;
tySequence__qwqHTkRvwhrRyENtudHQ7g* raiseFixups;
} _isTryBlock_2;
};
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyTuple__HQcnEvwXwW8nB4mw1aSc9bg {
NI Field0;
tySequence__IeU9azYSNIK3V9b36Ir6NZcw* Field1;
};
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NU8 tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg[9];
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tySet_tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw[21];
typedef NI tyArray__HU7qaqKu9czJLT84iCBJnsA[2];
typedef NU8 tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w;
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tySequence__7Ph69cTgZS9be09cTzR9afiJeA {
  TGenericSeq Sup;
  tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w data[SEQ_DECL_SIZE];
};
struct tySequence__z8L8BvgPZ9bdGD1gr7FvhEw {
  TGenericSeq Sup;
  tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__AO6tQ23B9aS9b43hhtsROhdQ {
  TGenericSeq Sup;
  tyTuple__HQcnEvwXwW8nB4mw1aSc9bg data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__AO6tQ23B9aS9b43hhtsROhdQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__z8L8BvgPZ9bdGD1gr7FvhEw)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, gen__dfa_200)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genUse__dfa_971)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* orig);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipTrivials__dfa_959)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_NIMCALL(void, Marker_tySequence__7Ph69cTgZS9be09cTzR9afiJeA)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, genMagic__dfa_1034)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m);
N_LIB_PRIVATE N_NIMCALL(void, genAndOr__dfa_460)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NI, forkI__dfa_83)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, patch__dfa_175)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, NI p);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__systemZassertions_56)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(void, genDef__dfa_987)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* orig);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genCall__dfa_1003)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*, skipTypes__ast_3723)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t, tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kinds);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaiseConservative__ast_5088)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fn);
N_LIB_PRIVATE N_NIMCALL(void, genBreakOrRaiseAux__dfa_571)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, NI i, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NI, gotoI__dfa_126)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5267)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, genIf__dfa_402)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genCase__dfa_467)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI*, X5BX5D___dfa_508)(NI* s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(void, genWhile__dfa_318)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTrue__dfa_303)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, popBlock__dfa_203)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, NI oldLen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNode__ast_3289)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, genBlock__dfa_557)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genReturn__dfa_784)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genImplicitReturn__dfa_774)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c);
N_LIB_PRIVATE N_NIMCALL(void, genRaise__dfa_747)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genBreak__dfa_625)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genTry__dfa_656)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, genVarSection__dfa_1048)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
static N_INLINE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**, X5BX5D___ast_4837)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** s, NI sLen_0, NI i);
static N_INLINE(NIM_BOOL, isSinkParam__ast_5042)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s);
N_LIB_PRIVATE TNimType NTItblock__fDjXGXL6cUaNFnT0rMSIiQ_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
TNimNode* NimDT___fDjXGXL6cUaNFnT0rMSIiQ_isTryBlock[3];
extern TNimType NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_;
N_LIB_PRIVATE TNimType NTILtposition_seqLpnodeTT__HQcnEvwXwW8nB4mw1aSc9bg_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_;
N_LIB_PRIVATE TNimType NTIseqLLtposition_seqLpnodeTTT__AO6tQ23B9aS9b43hhtsROhdQ_;
extern TNimType NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_;
extern TNimType NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_;
N_LIB_PRIVATE TNimType NTIseqLtblockT__z8L8BvgPZ9bdGD1gr7FvhEw_;
N_LIB_PRIVATE TNimType NTIinstr__M1JDxfxGyVaK5N9ctM7QW2w_;
N_LIB_PRIVATE TNimType NTIinstrkind__82Too4YSWL3lxgkmNlM6Mw_;
TNimNode* NimDT___M1JDxfxGyVaK5N9ctM7QW2w_kind[5];
N_LIB_PRIVATE TNimType NTIcontrolflowgraph__7Ph69cTgZS9be09cTzR9afiJeA_;
STRING_LITERAL(TM__9aNn2jEg4ezQBM0yZx8s2cA_9, "dfa.nim(272, 12) `low(int) div 2 + 1 < c.code.len - p.int and c.code.len - p.int < high(int) div 2` ", 100);
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9aNn2jEg4ezQBM0yZx8s2cA_10 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw TM__9aNn2jEg4ezQBM0yZx8s2cA_11 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0xe4, 0x00, 0x80,
0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9aNn2jEg4ezQBM0yZx8s2cA_12 = {
0x10, 0xa8, 0x90, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
STRING_LITERAL(TM__9aNn2jEg4ezQBM0yZx8s2cA_13, "dfa.nim(807, 24) `false` dfa construction pass requires the elimination of \'defer\'", 82);
N_LIB_PRIVATE TNimType NTIaliaskind__vyyqF5f609aD8pvRKZixr4w_;
static NIM_CONST tySet_tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg TM__9aNn2jEg4ezQBM0yZx8s2cA_17 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x40, 0x80, 0x00,
0x00}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5220;
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_NIMCALL(void, Marker_tySequence__AO6tQ23B9aS9b43hhtsROhdQ)(void* p, NI op) {
	tySequence__AO6tQ23B9aS9b43hhtsROhdQ* a;
	NI T1_;
	a = (tySequence__AO6tQ23B9aS9b43hhtsROhdQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__z8L8BvgPZ9bdGD1gr7FvhEw)(void* p, NI op) {
	tySequence__z8L8BvgPZ9bdGD1gr7FvhEw* a;
	NI T1_;
	a = (tySequence__z8L8BvgPZ9bdGD1gr7FvhEw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	switch (a->data[T1_].isTryBlock) {
	case NIM_FALSE:
	nimGCvisit((void*)a->data[T1_]._isTryBlock_1.label, op);
	nimGCvisit((void*)a->data[T1_]._isTryBlock_1.breakFixups, op);
	break;
	case NIM_TRUE:
	nimGCvisit((void*)a->data[T1_]._isTryBlock_2.finale, op);
	nimGCvisit((void*)a->data[T1_]._isTryBlock_2.raiseFixups, op);
	break;
	} 
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipTrivials__dfa_959)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = n;
	{
		while (1) {
			switch ((*result).kind) {
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
			{
				result = (*result)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
			{
				gen__dfa_200(c, (*result)._kind_6.sons->data[((NI) 1)]);
				result = (*result)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
			{
				result = (*result)._kind_6.sons->data[((NI) 1)];
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	return result;
}
static N_NIMCALL(void, Marker_tySequence__7Ph69cTgZS9be09cTzR9afiJeA)(void* p, NI op) {
	tySequence__7Ph69cTgZS9be09cTzR9afiJeA* a;
	NI T1_;
	a = (tySequence__7Ph69cTgZS9be09cTzR9afiJeA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].n, op);
	switch (a->data[T1_].kind) {
	case ((tyEnum_InstrKind__82Too4YSWL3lxgkmNlM6Mw) 0):
	case ((tyEnum_InstrKind__82Too4YSWL3lxgkmNlM6Mw) 1):
	break;
	default:
	break;
	} 
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genUse__dfa_971)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* orig) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
	n = skipTrivials__dfa_959(c, orig);
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA3_;
		{
			tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w T9_;
			NI T10_;
			if (!((2100008 &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0)) goto LA7_;
			nimZeroMem((void*)(&T9_), sizeof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w));
			nimZeroMem((void*)(&T9_), sizeof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w));
			T9_.n = orig;
			T9_.kind = ((tyEnum_InstrKind__82Too4YSWL3lxgkmNlM6Mw) 3);
			unsureAsgnRef((void**) (&(*c).code), (tySequence__7Ph69cTgZS9be09cTzR9afiJeA*) incrSeqV3((TGenericSeq*)((*c).code), (&NTIcontrolflowgraph__7Ph69cTgZS9be09cTzR9afiJeA_)));
			T10_ = (*c).code->Sup.len++;
			genericAssign((void*)(&(*c).code->data[T10_]), (void*)(&T9_), (&NTIinstr__M1JDxfxGyVaK5N9ctM7QW2w_));
		}
		LA7_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		gen__dfa_200(c, n);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, forkI__dfa_83)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w T2_;
	NI T3_;
	result = (NI)0;
	T1_ = ((*c).code ? (*c).code->Sup.len : 0);
	result = T1_;
	nimZeroMem((void*)(&T2_), sizeof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w));
	nimZeroMem((void*)(&T2_), sizeof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w));
	T2_.n = n;
	T2_.kind = ((tyEnum_InstrKind__82Too4YSWL3lxgkmNlM6Mw) 1);
	T2_.dest = ((NI) 0);
	unsureAsgnRef((void**) (&(*c).code), (tySequence__7Ph69cTgZS9be09cTzR9afiJeA*) incrSeqV3((TGenericSeq*)((*c).code), (&NTIcontrolflowgraph__7Ph69cTgZS9be09cTzR9afiJeA_)));
	T3_ = (*c).code->Sup.len++;
	genericAssign((void*)(&(*c).code->data[T3_]), (void*)(&T2_), (&NTIinstr__M1JDxfxGyVaK5N9ctM7QW2w_));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, patch__dfa_175)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, NI p) {
	NI T9_;
	{
		NIM_BOOL T3_;
		NI T4_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = ((*c).code ? (*c).code->Sup.len : 0);
		T3_ = (((NI) IL64(-4611686018427387903)) < (NI)(T4_ - p));
		if (!(T3_)) goto LA5_;
		T6_ = ((*c).code ? (*c).code->Sup.len : 0);
		T3_ = ((NI)(T6_ - p) < ((NI) IL64(4611686018427387903)));
		LA5_: ;
		if (!!(T3_)) goto LA7_;
		failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__9aNn2jEg4ezQBM0yZx8s2cA_9));
	}
	LA7_: ;
	T9_ = ((*c).code ? (*c).code->Sup.len : 0);
	(*c).code->data[p].dest = (NI)(T9_ - p);
}
N_LIB_PRIVATE N_NIMCALL(void, genAndOr__dfa_460)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI lab1X60gensym28_;
	gen__dfa_200(c, (*n)._kind_6.sons->data[((NI) 1)]);
	lab1X60gensym28_ = forkI__dfa_83(c, n);
	gen__dfa_200(c, (*n)._kind_6.sons->data[((NI) 2)]);
	patch__dfa_175(c, lab1X60gensym28_);
}
N_LIB_PRIVATE N_NIMCALL(void, genDef__dfa_987)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* orig) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
	n = skipTrivials__dfa_959(c, orig);
	{
		NIM_BOOL T3_;
		tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w T7_;
		NI T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = ((2100008 &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		nimZeroMem((void*)(&T7_), sizeof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w));
		nimZeroMem((void*)(&T7_), sizeof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w));
		T7_.n = orig;
		T7_.kind = ((tyEnum_InstrKind__82Too4YSWL3lxgkmNlM6Mw) 2);
		unsureAsgnRef((void**) (&(*c).code), (tySequence__7Ph69cTgZS9be09cTzR9afiJeA*) incrSeqV3((TGenericSeq*)((*c).code), (&NTIcontrolflowgraph__7Ph69cTgZS9be09cTzR9afiJeA_)));
		T8_ = (*c).code->Sup.len++;
		genericAssign((void*)(&(*c).code->data[T8_]), (void*)(&T7_), (&NTIinstr__M1JDxfxGyVaK5N9ctM7QW2w_));
	}
	LA5_: ;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, gotoI__dfa_126)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w T2_;
	NI T3_;
	result = (NI)0;
	T1_ = ((*c).code ? (*c).code->Sup.len : 0);
	result = T1_;
	nimZeroMem((void*)(&T2_), sizeof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w));
	nimZeroMem((void*)(&T2_), sizeof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w));
	T2_.n = n;
	T2_.kind = ((tyEnum_InstrKind__82Too4YSWL3lxgkmNlM6Mw) 0);
	T2_.dest = ((NI) 0);
	unsureAsgnRef((void**) (&(*c).code), (tySequence__7Ph69cTgZS9be09cTzR9afiJeA*) incrSeqV3((TGenericSeq*)((*c).code), (&NTIcontrolflowgraph__7Ph69cTgZS9be09cTzR9afiJeA_)));
	T3_ = (*c).code->Sup.len++;
	genericAssign((void*)(&(*c).code->data[T3_]), (void*)(&T2_), (&NTIinstr__M1JDxfxGyVaK5N9ctM7QW2w_));
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5267((&gch__system_5220.zct), c);
}
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5316(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5273(src);
		incRef__system_5311(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5273((*dest));
		decRef__system_5318(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, genBreakOrRaiseAux__dfa_571)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, NI i, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI lab1;
	lab1 = gotoI__dfa_126(c, n);
	{
		NI T5_;
		if (!(*c).blocks->data[i].isTryBlock) goto LA3_;
		asgnRef((void**) (&(*c).blocks->data[i]._isTryBlock_2.raiseFixups), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*c).blocks->data[i]._isTryBlock_2.raiseFixups), (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_)));
		T5_ = (*c).blocks->data[i]._isTryBlock_2.raiseFixups->Sup.len++;
		(*c).blocks->data[i]._isTryBlock_2.raiseFixups->data[T5_] = lab1;
	}
	goto LA1_;
	LA3_: ;
	{
		tySequence__IeU9azYSNIK3V9b36Ir6NZcw* trailingFinales;
		tyTuple__HQcnEvwXwW8nB4mw1aSc9bg T20_;
		NI T21_;
		trailingFinales = NIM_NIL;
		{
			if (!(((NI) 0) < (*c).inTryStmt)) goto LA9_;
			{
				NI b;
				NI colontmp_;
				NI T12_;
				NI res;
				b = (NI)0;
				colontmp_ = (NI)0;
				T12_ = (((*c).blocks ? (*c).blocks->Sup.len : 0)-1);
				colontmp_ = T12_;
				res = colontmp_;
				{
					while (1) {
						if (!(i <= res)) goto LA14;
						b = res;
						{
							NI T19_;
							if (!(*c).blocks->data[b].isTryBlock) goto LA17_;
							trailingFinales = (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) incrSeqV3((TGenericSeq*)(trailingFinales), (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_));
							T19_ = trailingFinales->Sup.len++;
							asgnRef((void**) (&trailingFinales->data[T19_]), (*c).blocks->data[b]._isTryBlock_2.finale);
						}
						LA17_: ;
						res -= ((NI) 1);
					} LA14: ;
				}
			}
		}
		LA9_: ;
		nimZeroMem((void*)(&T20_), sizeof(tyTuple__HQcnEvwXwW8nB4mw1aSc9bg));
		T20_.Field0 = lab1;
		genericSeqAssign((&T20_.Field1), trailingFinales, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_));
		asgnRef((void**) (&(*c).blocks->data[i]._isTryBlock_1.breakFixups), (tySequence__AO6tQ23B9aS9b43hhtsROhdQ*) incrSeqV3((TGenericSeq*)((*c).blocks->data[i]._isTryBlock_1.breakFixups), (&NTIseqLLtposition_seqLpnodeTTT__AO6tQ23B9aS9b43hhtsROhdQ_)));
		T21_ = (*c).blocks->data[i]._isTryBlock_1.breakFixups->Sup.len++;
		(*c).blocks->data[i]._isTryBlock_1.breakFixups->data[T21_].Field0 = T20_.Field0;
		genericSeqAssign((&(*c).blocks->data[i]._isTryBlock_1.breakFixups->data[T21_].Field1), T20_.Field1, (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCall__dfa_1003)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* t;
	gen__dfa_200(c, (*n)._kind_6.sons->data[((NI) 0)]);
	t = (*(*n)._kind_6.sons->data[((NI) 0)]).typ;
	{
		if (!!((t == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA3_;
		t = skipTypes__ast_3723(t, TM__9aNn2jEg4ezQBM0yZx8s2cA_10);
	}
	LA3_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA7;
				i = i_2;
				gen__dfa_200(c, (*n)._kind_6.sons->data[i]);
				i_2 += ((NI) 1);
			} LA7: ;
		}
	}
	{
		NIM_BOOL T10_;
		NI lab1X60gensym109_;
		T10_ = (NIM_BOOL)0;
		T10_ = (((NI) 0) < (*c).inTryStmt);
		if (!(T10_)) goto LA11_;
		T10_ = canRaiseConservative__ast_5088((*n)._kind_6.sons->data[((NI) 0)]);
		LA11_: ;
		if (!T10_) goto LA12_;
		lab1X60gensym109_ = forkI__dfa_83(c, n);
		{
			NI i_3;
			NI colontmp__2;
			NI T15_;
			NI res;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			T15_ = (((*c).blocks ? (*c).blocks->Sup.len : 0)-1);
			colontmp__2 = T15_;
			res = colontmp__2;
			{
				while (1) {
					if (!(((NI) 0) <= res)) goto LA17;
					i_3 = res;
					{
						if (!(*c).blocks->data[i_3].isTryBlock) goto LA20_;
						genBreakOrRaiseAux__dfa_571(c, i_3, n);
						goto LA14;
					}
					LA20_: ;
					res -= ((NI) 1);
				} LA17: ;
			}
		} LA14: ;
		patch__dfa_175(c, lab1X60gensym109_);
	}
	LA12_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genMagic__dfa_1034)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag m) {
	switch (m) {
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 109):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 110):
	{
		genAndOr__dfa_460(c, n);
	}
	break;
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 32):
	case ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 33):
	{
		genDef__dfa_987(c, (*n)._kind_6.sons->data[((NI) 1)]);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 2);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA5;
					i = i_2;
					gen__dfa_200(c, (*n)._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA5: ;
			}
		}
	}
	break;
	default:
	{
		genCall__dfa_1003(c, n);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genIf__dfa_402)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tySequence__qwqHTkRvwhrRyENtudHQ7g* endings;
	endings = NIM_NIL;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				gen__dfa_200(c, (*it)._kind_6.sons->data[((NI) 0)]);
				{
					NI T6_;
					NI lab1X60gensym23_;
					NI T9_;
					NI T10_;
					T6_ = (NI)0;
					T6_ = len__ast_3155(it);
					if (!(T6_ == ((NI) 2))) goto LA7_;
					lab1X60gensym23_ = forkI__dfa_83(c, (*it)._kind_6.sons->data[((NI) 1)]);
					gen__dfa_200(c, (*it)._kind_6.sons->data[((NI) 1)]);
					T9_ = (NI)0;
					T9_ = gotoI__dfa_126(c, (*it)._kind_6.sons->data[((NI) 1)]);
					endings = (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)(endings), (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_));
					T10_ = endings->Sup.len++;
					endings->data[T10_] = T9_;
					patch__dfa_175(c, lab1X60gensym23_);
				}
				LA7_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	{
		NI i_3;
		NI colontmp__2;
		NI T12_;
		NI res;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		T12_ = ((endings ? endings->Sup.len : 0)-1);
		colontmp__2 = T12_;
		res = colontmp__2;
		{
			while (1) {
				if (!(((NI) 0) <= res)) goto LA14;
				i_3 = res;
				patch__dfa_175(c, endings->data[i_3]);
				res -= ((NI) 1);
			} LA14: ;
		}
	}
}
static N_INLINE(NI*, X5BX5D___dfa_508)(NI* s, NI sLen_0, NI i) {
	NI* result;
	result = (NI*)0;
	result = (&s[(NI)(sLen_0 - i)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genCase__dfa_467)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL isExhaustive;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T1_;
	tySequence__qwqHTkRvwhrRyENtudHQ7g* endings;
	T1_ = NIM_NIL;
	T1_ = skipTypes__ast_3723((*(*n)._kind_6.sons->data[((NI) 0)]).typ, TM__9aNn2jEg4ezQBM0yZx8s2cA_12);
	isExhaustive = !(((*T1_).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) && (*T1_).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39) || (*T1_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 28)));
	endings = NIM_NIL;
	gen__dfa_200(c, (*n)._kind_6.sons->data[((NI) 0)]);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					NIM_BOOL T7_;
					NI T8_;
					NIM_BOOL T10_;
					NI T11_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T15_;
					T7_ = (NIM_BOOL)0;
					T8_ = (NI)0;
					T8_ = len__ast_3155(it);
					T7_ = (T8_ == ((NI) 1));
					if (T7_) goto LA9_;
					T10_ = (NIM_BOOL)0;
					T11_ = (NI)0;
					T11_ = len__ast_3155(n);
					T10_ = (i == (NI)(T11_ - ((NI) 1)));
					if (!(T10_)) goto LA12_;
					T10_ = isExhaustive;
					LA12_: ;
					T7_ = T10_;
					LA9_: ;
					if (!T7_) goto LA13_;
					T15_ = NIM_NIL;
					T15_ = lastSon__ast_4833(it);
					gen__dfa_200(c, T15_);
					{
						NI T18_;
						NI* T21_;
						T18_ = (endings ? endings->Sup.len : 0);
						if (!!((T18_ == ((NI) 0)))) goto LA19_;
						T21_ = (NI*)0;
						T21_ = X5BX5D___dfa_508((endings) ? (endings->data) : NIM_NIL, (endings ? endings->Sup.len : 0), ((NI) 1));
						patch__dfa_175(c, (*T21_));
					}
					LA19_: ;
				}
				goto LA5_;
				LA13_: ;
				{
					NI lab1X60gensym36_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T23_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T24_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T31_;
					NI T32_;
					NI T33_;
					T23_ = NIM_NIL;
					T23_ = lastSon__ast_4833(it);
					lab1X60gensym36_ = forkI__dfa_83(c, T23_);
					T24_ = NIM_NIL;
					T24_ = lastSon__ast_4833(it);
					gen__dfa_200(c, T24_);
					{
						NI T27_;
						NI* T30_;
						T27_ = (endings ? endings->Sup.len : 0);
						if (!!((T27_ == ((NI) 0)))) goto LA28_;
						T30_ = (NI*)0;
						T30_ = X5BX5D___dfa_508((endings) ? (endings->data) : NIM_NIL, (endings ? endings->Sup.len : 0), ((NI) 1));
						patch__dfa_175(c, (*T30_));
					}
					LA28_: ;
					T31_ = NIM_NIL;
					T31_ = lastSon__ast_4833(it);
					T32_ = (NI)0;
					T32_ = gotoI__dfa_126(c, T31_);
					endings = (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)(endings), (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_));
					T33_ = endings->Sup.len++;
					endings->data[T33_] = T32_;
					patch__dfa_175(c, lab1X60gensym36_);
				}
				LA5_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTrue__dfa_303)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	NIM_BOOL T7_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
	if (!(T3_)) goto LA4_;
	T3_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 20));
	LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA5_;
	T2_ = !(((*(*n)._kind_4.sym).position == ((NI) 0)));
	LA5_: ;
	T1_ = T2_;
	if (T1_) goto LA6_;
	T7_ = (NIM_BOOL)0;
	T7_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 6));
	if (!(T7_)) goto LA8_;
	T7_ = !(((*n)._kind_1.intVal == IL64(0)));
	LA8_: ;
	T1_ = T7_;
	LA6_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, popBlock__dfa_203)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, NI oldLen) {
	tySequence__qwqHTkRvwhrRyENtudHQ7g* exits;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T1_;
	NI T2_;
	NI T3_;
	exits = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
	T2_ = (NI)0;
	T2_ = gotoI__dfa_126(c, T1_);
	exits = (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)(exits), (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_));
	T3_ = exits->Sup.len++;
	exits->data[T3_] = T2_;
	{
		tyTuple__HQcnEvwXwW8nB4mw1aSc9bg* f;
		tySequence__AO6tQ23B9aS9b43hhtsROhdQ* colontmp_;
		NI i;
		NI L;
		NI T5_;
		f = (tyTuple__HQcnEvwXwW8nB4mw1aSc9bg*)0;
		colontmp_ = NIM_NIL;
		colontmp_ = (*c).blocks->data[oldLen]._isTryBlock_1.breakFixups;
		i = ((NI) 0);
		T5_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T5_;
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T12_;
				NI T13_;
				NI T14_;
				if (!(i < L)) goto LA7;
				f = (&colontmp_->data[i]);
				patch__dfa_175(c, (*f).Field0);
				{
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** finale;
					tySequence__IeU9azYSNIK3V9b36Ir6NZcw* colontmp__2;
					NI i_2;
					NI L_2;
					NI T9_;
					finale = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
					colontmp__2 = NIM_NIL;
					colontmp__2 = (*f).Field1;
					i_2 = ((NI) 0);
					T9_ = (colontmp__2 ? colontmp__2->Sup.len : 0);
					L_2 = T9_;
					{
						while (1) {
							if (!(i_2 < L_2)) goto LA11;
							finale = &colontmp__2->data[i_2];
							gen__dfa_200(c, (*finale));
							i_2 += ((NI) 1);
						} LA11: ;
					}
				}
				T12_ = NIM_NIL;
				T12_ = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
				T13_ = (NI)0;
				T13_ = gotoI__dfa_126(c, T12_);
				exits = (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)(exits), (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_));
				T14_ = exits->Sup.len++;
				exits->data[T14_] = T13_;
				i += ((NI) 1);
			} LA7: ;
		}
	}
	{
		NI* e;
		NI i_3;
		NI L_3;
		NI T16_;
		e = (NI*)0;
		i_3 = ((NI) 0);
		T16_ = (exits ? exits->Sup.len : 0);
		L_3 = T16_;
		{
			while (1) {
				if (!(i_3 < L_3)) goto LA18;
				e = (&exits->data[i_3]);
				patch__dfa_175(c, (*e));
				i_3 += ((NI) 1);
			} LA18: ;
		}
	}
	unsureAsgnRef((void**) (&(*c).blocks), (tySequence__z8L8BvgPZ9bdGD1gr7FvhEw*) setLengthSeqV2(((*c).blocks)?&((*c).blocks)->Sup:NIM_NIL, (&NTIseqLtblockT__z8L8BvgPZ9bdGD1gr7FvhEw_), ((NI) (oldLen))));
}
N_LIB_PRIVATE N_NIMCALL(void, genWhile__dfa_318)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		NIM_BOOL T3_;
		NI oldLenX60gensym16_;
		NI T6_;
		tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ T7_;
		NI T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = isTrue__dfa_303((*n)._kind_6.sons->data[((NI) 0)]);
		if (!T3_) goto LA4_;
		T6_ = ((*c).blocks ? (*c).blocks->Sup.len : 0);
		oldLenX60gensym16_ = T6_;
		nimZeroMem((void*)(&T7_), sizeof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ));
		nimZeroMem((void*)(&T7_), sizeof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ));
		T7_.isTryBlock = NIM_FALSE;
		T7_._isTryBlock_1.label = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
		unsureAsgnRef((void**) (&(*c).blocks), (tySequence__z8L8BvgPZ9bdGD1gr7FvhEw*) incrSeqV3((TGenericSeq*)((*c).blocks), (&NTIseqLtblockT__z8L8BvgPZ9bdGD1gr7FvhEw_)));
		T8_ = (*c).blocks->Sup.len++;
		genericAssign((void*)(&(*c).blocks->data[T8_]), (void*)(&T7_), (&NTItblock__fDjXGXL6cUaNFnT0rMSIiQ_));
		{
			NI i;
			NI res;
			i = (NI)0;
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= ((NI) 1))) goto LA11;
					i = res;
					gen__dfa_200(c, (*n)._kind_6.sons->data[((NI) 1)]);
					res += ((NI) 1);
				} LA11: ;
			}
		}
		popBlock__dfa_203(c, oldLenX60gensym16_);
	}
	goto LA1_;
	LA4_: ;
	{
		NI oldLenX60gensym18_;
		NI T13_;
		tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ T14_;
		NI T15_;
		tyArray__HU7qaqKu9czJLT84iCBJnsA endings;
		T13_ = ((*c).blocks ? (*c).blocks->Sup.len : 0);
		oldLenX60gensym18_ = T13_;
		nimZeroMem((void*)(&T14_), sizeof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ));
		nimZeroMem((void*)(&T14_), sizeof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ));
		T14_.isTryBlock = NIM_FALSE;
		T14_._isTryBlock_1.label = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
		unsureAsgnRef((void**) (&(*c).blocks), (tySequence__z8L8BvgPZ9bdGD1gr7FvhEw*) incrSeqV3((TGenericSeq*)((*c).blocks), (&NTIseqLtblockT__z8L8BvgPZ9bdGD1gr7FvhEw_)));
		T15_ = (*c).blocks->Sup.len++;
		genericAssign((void*)(&(*c).blocks->data[T15_]), (void*)(&T14_), (&NTItblock__fDjXGXL6cUaNFnT0rMSIiQ_));
		nimZeroMem((void*)endings, sizeof(tyArray__HU7qaqKu9czJLT84iCBJnsA));
		{
			NI i_2;
			NI res_2;
			i_2 = (NI)0;
			res_2 = ((NI) 0);
			{
				while (1) {
					if (!(res_2 <= ((NI) 1))) goto LA18;
					i_2 = res_2;
					gen__dfa_200(c, (*n)._kind_6.sons->data[((NI) 0)]);
					endings[(i_2)- 0] = forkI__dfa_83(c, n);
					gen__dfa_200(c, (*n)._kind_6.sons->data[((NI) 1)]);
					res_2 += ((NI) 1);
				} LA18: ;
			}
		}
		{
			NI i_3;
			NI res_3;
			i_3 = (NI)0;
			res_3 = ((NI) 1);
			{
				while (1) {
					if (!(((NI) 0) <= res_3)) goto LA21;
					i_3 = ((NI) (res_3));
					patch__dfa_175(c, endings[(i_3)- 0]);
					res_3 -= ((NI) 1);
				} LA21: ;
			}
		}
		popBlock__dfa_203(c, oldLenX60gensym18_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBlock__dfa_557)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI oldLenX60gensym40_;
	NI T1_;
	tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ T2_;
	NI T3_;
	T1_ = ((*c).blocks ? (*c).blocks->Sup.len : 0);
	oldLenX60gensym40_ = T1_;
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ));
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ));
	T2_.isTryBlock = NIM_FALSE;
	T2_._isTryBlock_1.label = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	unsureAsgnRef((void**) (&(*c).blocks), (tySequence__z8L8BvgPZ9bdGD1gr7FvhEw*) incrSeqV3((TGenericSeq*)((*c).blocks), (&NTIseqLtblockT__z8L8BvgPZ9bdGD1gr7FvhEw_)));
	T3_ = (*c).blocks->Sup.len++;
	genericAssign((void*)(&(*c).blocks->data[T3_]), (void*)(&T2_), (&NTItblock__fDjXGXL6cUaNFnT0rMSIiQ_));
	gen__dfa_200(c, (*n)._kind_6.sons->data[((NI) 1)]);
	popBlock__dfa_203(c, oldLenX60gensym40_);
}
N_LIB_PRIVATE N_NIMCALL(void, genImplicitReturn__dfa_774)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c) {
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((126976 &((NU32)1<<((NU)((*(*c).owner).kind)&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__ast_3155((*(*c).owner).ast);
		T3_ = (((NI) 7) < T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		gen__dfa_200(c, (*(*(*c).owner).ast)._kind_6.sons->data[((NI) 7)]);
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genReturn__dfa_784)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA3_;
		gen__dfa_200(c, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	goto LA1_;
	LA3_: ;
	{
		genImplicitReturn__dfa_774(c);
	}
	LA1_: ;
	genBreakOrRaiseAux__dfa_571(c, ((NI) 0), n);
}
N_LIB_PRIVATE N_NIMCALL(void, genRaise__dfa_747)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
{	gen__dfa_200(c, (*n)._kind_6.sons->data[((NI) 0)]);
	{
		if (!(((NI) 0) < (*c).inTryStmt)) goto LA3_;
		{
			NI i;
			NI colontmp_;
			NI T6_;
			NI res;
			i = (NI)0;
			colontmp_ = (NI)0;
			T6_ = (((*c).blocks ? (*c).blocks->Sup.len : 0)-1);
			colontmp_ = T6_;
			res = colontmp_;
			{
				while (1) {
					if (!(((NI) 0) <= res)) goto LA8;
					i = res;
					{
						if (!(*c).blocks->data[i].isTryBlock) goto LA11_;
						genBreakOrRaiseAux__dfa_571(c, i, n);
						goto BeforeRet_;
					}
					LA11_: ;
					res -= ((NI) 1);
				} LA8: ;
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w T14_;
		NI T15_;
		NI T16_;
		nimZeroMem((void*)(&T14_), sizeof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w));
		nimZeroMem((void*)(&T14_), sizeof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w));
		T14_.n = n;
		T14_.kind = ((tyEnum_InstrKind__82Too4YSWL3lxgkmNlM6Mw) 0);
		T15_ = ((*c).code ? (*c).code->Sup.len : 0);
		T14_.dest = (NI)(((NI) IL64(9223372036854775807)) - T15_);
		unsureAsgnRef((void**) (&(*c).code), (tySequence__7Ph69cTgZS9be09cTzR9afiJeA*) incrSeqV3((TGenericSeq*)((*c).code), (&NTIcontrolflowgraph__7Ph69cTgZS9be09cTzR9afiJeA_)));
		T16_ = (*c).code->Sup.len++;
		genericAssign((void*)(&(*c).code->data[T16_]), (void*)(&T14_), (&NTIinstr__M1JDxfxGyVaK5N9ctM7QW2w_));
	}
	LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBreak__dfa_625)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
{	{
		if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA3_;
		{
			NI i;
			NI colontmp_;
			NI T6_;
			NI res;
			i = (NI)0;
			colontmp_ = (NI)0;
			T6_ = (((*c).blocks ? (*c).blocks->Sup.len : 0)-1);
			colontmp_ = T6_;
			res = colontmp_;
			{
				while (1) {
					if (!(((NI) 0) <= res)) goto LA8;
					i = res;
					{
						NIM_BOOL T11_;
						T11_ = (NIM_BOOL)0;
						T11_ = !((*c).blocks->data[i].isTryBlock);
						if (!(T11_)) goto LA12_;
						T11_ = ((*c).blocks->data[i]._isTryBlock_1.label == (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
						LA12_: ;
						if (!T11_) goto LA13_;
						genBreakOrRaiseAux__dfa_571(c, i, n);
						goto BeforeRet_;
					}
					LA13_: ;
					res -= ((NI) 1);
				} LA8: ;
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NI i_2;
			NI colontmp__2;
			NI T17_;
			NI res_2;
			i_2 = (NI)0;
			colontmp__2 = (NI)0;
			T17_ = (((*c).blocks ? (*c).blocks->Sup.len : 0)-1);
			colontmp__2 = T17_;
			res_2 = colontmp__2;
			{
				while (1) {
					if (!(((NI) 0) <= res_2)) goto LA19;
					i_2 = res_2;
					{
						if (!!((*c).blocks->data[i_2].isTryBlock)) goto LA22_;
						genBreakOrRaiseAux__dfa_571(c, i_2, n);
						goto BeforeRet_;
					}
					LA22_: ;
					res_2 -= ((NI) 1);
				} LA19: ;
			}
		}
	}
	LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTry__dfa_656)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tySequence__qwqHTkRvwhrRyENtudHQ7g* endings;
	NI oldLen;
	NI T1_;
	tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ T2_;
	NI T10_;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* fin;
	endings = NIM_NIL;
	T1_ = ((*c).blocks ? (*c).blocks->Sup.len : 0);
	oldLen = T1_;
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ));
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ));
	T2_.isTryBlock = NIM_TRUE;
	{
		NI T5_;
		NI T8_;
		T5_ = (NI)0;
		T5_ = len__ast_3155(n);
		if (!((*(*n)._kind_6.sons->data[(NI)(T5_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 107))) goto LA6_;
		T8_ = (NI)0;
		T8_ = len__ast_3155(n);
		T2_._isTryBlock_2.finale = (*n)._kind_6.sons->data[(NI)(T8_ - ((NI) 1))];
	}
	goto LA3_;
	LA6_: ;
	{
		T2_._isTryBlock_2.finale = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*c).blocks), (tySequence__z8L8BvgPZ9bdGD1gr7FvhEw*) incrSeqV3((TGenericSeq*)((*c).blocks), (&NTIseqLtblockT__z8L8BvgPZ9bdGD1gr7FvhEw_)));
	T10_ = (*c).blocks->Sup.len++;
	genericAssign((void*)(&(*c).blocks->data[T10_]), (void*)(&T2_), (&NTItblock__fDjXGXL6cUaNFnT0rMSIiQ_));
	(*c).inTryStmt += ((NI) 1);
	gen__dfa_200(c, (*n)._kind_6.sons->data[((NI) 0)]);
	(*c).inTryStmt -= ((NI) 1);
	{
		NI* f;
		tySequence__qwqHTkRvwhrRyENtudHQ7g* colontmp_;
		NI i;
		NI L;
		NI T12_;
		f = (NI*)0;
		colontmp_ = NIM_NIL;
		colontmp_ = (*c).blocks->data[oldLen]._isTryBlock_2.raiseFixups;
		i = ((NI) 0);
		T12_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T12_;
		{
			while (1) {
				if (!(i < L)) goto LA14;
				f = (&colontmp_->data[i]);
				patch__dfa_175(c, (*f));
				i += ((NI) 1);
			} LA14: ;
		}
	}
	unsureAsgnRef((void**) (&(*c).blocks), (tySequence__z8L8BvgPZ9bdGD1gr7FvhEw*) setLengthSeqV2(((*c).blocks)?&((*c).blocks)->Sup:NIM_NIL, (&NTIseqLtblockT__z8L8BvgPZ9bdGD1gr7FvhEw_), ((NI) (oldLen))));
	{
		NI i_2;
		NI colontmp__2;
		NI i_3;
		i_2 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = len__ast_3155(n);
		i_3 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* it;
				if (!(i_3 < colontmp__2)) goto LA17;
				i_2 = i_3;
				it = (*n)._kind_6.sons->data[i_2];
				{
					NI lab1X60gensym54_;
					tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T22_;
					NI T23_;
					NI T24_;
					if (!!(((*it).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 107)))) goto LA20_;
					lab1X60gensym54_ = forkI__dfa_83(c, it);
					T22_ = NIM_NIL;
					T22_ = lastSon__ast_4833(it);
					gen__dfa_200(c, T22_);
					T23_ = (NI)0;
					T23_ = gotoI__dfa_126(c, it);
					endings = (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)(endings), (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_));
					T24_ = endings->Sup.len++;
					endings->data[T24_] = T23_;
					patch__dfa_175(c, lab1X60gensym54_);
				}
				LA20_: ;
				i_3 += ((NI) 1);
			} LA17: ;
		}
	}
	{
		NI i_4;
		NI colontmp__3;
		NI T26_;
		NI res;
		i_4 = (NI)0;
		colontmp__3 = (NI)0;
		T26_ = ((endings ? endings->Sup.len : 0)-1);
		colontmp__3 = T26_;
		res = colontmp__3;
		{
			while (1) {
				if (!(((NI) 0) <= res)) goto LA28;
				i_4 = res;
				patch__dfa_175(c, endings->data[i_4]);
				res -= ((NI) 1);
			} LA28: ;
		}
	}
	fin = lastSon__ast_4833(n);
	{
		if (!((*fin).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 107))) goto LA31_;
		gen__dfa_200(c, (*fin)._kind_6.sons->data[((NI) 0)]);
	}
	LA31_: ;
}
static N_INLINE(NI, safeLen__ast_3148)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 0) && (*n).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__ast_3155(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genVarSection__dfa_1048)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
		a = NIM_NIL;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_3148(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					a = (*n)._kind_6.sons->data[i];
					{
						if (!((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 125))) goto LA7_;
					}
					goto LA5_;
					LA7_: ;
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T12_;
						if (!((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 36))) goto LA10_;
						T12_ = NIM_NIL;
						T12_ = lastSon__ast_4833(a);
						gen__dfa_200(c, T12_);
						{
							NI i_3;
							NI colontmp__2;
							NI T14_;
							NI i_4;
							i_3 = (NI)0;
							colontmp__2 = (NI)0;
							T14_ = (NI)0;
							T14_ = len__ast_3155(a);
							colontmp__2 = (NI)(T14_ - ((NI) 2));
							i_4 = ((NI) 0);
							{
								while (1) {
									if (!(i_4 < colontmp__2)) goto LA16;
									i_3 = i_4;
									genDef__dfa_987(c, (*a)._kind_6.sons->data[i_3]);
									i_4 += ((NI) 1);
								} LA16: ;
							}
						}
					}
					goto LA5_;
					LA10_: ;
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T18_;
						T18_ = NIM_NIL;
						T18_ = lastSon__ast_4833(a);
						gen__dfa_200(c, T18_);
						{
							tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T21_;
							T21_ = NIM_NIL;
							T21_ = lastSon__ast_4833(a);
							if (!!(((*T21_).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1)))) goto LA22_;
							genDef__dfa_987(c, (*a)._kind_6.sons->data[((NI) 0)]);
						}
						LA22_: ;
					}
					LA5_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, gen__dfa_200)(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ* c, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		genUse__dfa_971(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		{
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s;
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA5_;
			s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
			{
				if (!!(((*s).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 0)))) goto LA9_;
				genMagic__dfa_1034(c, n, (*s).magic);
			}
			goto LA7_;
			LA9_: ;
			{
				genCall__dfa_1003(c, n);
			}
			LA7_: ;
			{
				tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w T16_;
				NI T17_;
				NI T18_;
				if (!(((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 16))&63U)))!=0)) goto LA14_;
				nimZeroMem((void*)(&T16_), sizeof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w));
				nimZeroMem((void*)(&T16_), sizeof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w));
				T16_.n = n;
				T16_.kind = ((tyEnum_InstrKind__82Too4YSWL3lxgkmNlM6Mw) 0);
				T17_ = ((*c).code ? (*c).code->Sup.len : 0);
				T16_.dest = (NI)(((NI) IL64(9223372036854775807)) - T17_);
				unsureAsgnRef((void**) (&(*c).code), (tySequence__7Ph69cTgZS9be09cTzR9afiJeA*) incrSeqV3((TGenericSeq*)((*c).code), (&NTIcontrolflowgraph__7Ph69cTgZS9be09cTzR9afiJeA_)));
				T18_ = (*c).code->Sup.len++;
				genericAssign((void*)(&(*c).code->data[T18_]), (void*)(&T16_), (&NTIinstr__M1JDxfxGyVaK5N9ctM7QW2w_));
			}
			LA14_: ;
		}
		goto LA3_;
		LA5_: ;
		{
			genCall__dfa_1003(c, n);
		}
		LA3_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 23):
	{
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 73):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 74):
	{
		gen__dfa_200(c, (*n)._kind_6.sons->data[((NI) 1)]);
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a;
			if (!((TM__9aNn2jEg4ezQBM0yZx8s2cA_11[(NU)((*(*n)._kind_6.sons->data[((NI) 0)]).kind)>>3] &(1U<<((NU)((*(*n)._kind_6.sons->data[((NI) 0)]).kind)&7U)))!=0)) goto LA24_;
			a = skipTrivials__dfa_959(c, (*n)._kind_6.sons->data[((NI) 0)]);
			{
				if (!((*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*a).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32))) goto LA28_;
				gen__dfa_200(c, a);
			}
			LA28_: ;
		}
		LA24_: ;
		genDef__dfa_987(c, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65):
	{
		genUse__dfa_971(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 92):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 48):
	{
		genIf__dfa_402(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 93):
	{
		gen__dfa_200(c, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 97):
	{
		genCase__dfa_467(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 96):
	{
		genWhile__dfa_318(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 127):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 112):
	{
		genBlock__dfa_557(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 109):
	{
		genReturn__dfa_784(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 108):
	{
		genRaise__dfa_747(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 110):
	{
		genBreak__dfa_625(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 106):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 154):
	{
		genTry__dfa_656(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 126):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 68):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 69):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 70):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 41):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 39):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 37):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 160):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 38):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 104):
	{
		{
			tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* x;
			x = NIM_NIL;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_3148(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA44;
						i = i_2;
						x = (*n)._kind_6.sons->data[i];
						gen__dfa_200(c, x);
						i_2 += ((NI) 1);
					} LA44: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 91):
	{
		tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T46_;
		T46_ = NIM_NIL;
		T46_ = lastSon__ast_4833(n);
		gen__dfa_200(c, T46_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 114):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 71):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 72):
	{
		gen__dfa_200(c, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 60):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 34):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 33):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 61):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
	{
		gen__dfa_200(c, (*n)._kind_6.sons->data[((NI) 1)]);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 99):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 100):
	{
		genVarSection__dfa_1048(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 105):
	{
		{
			if (!NIM_TRUE) goto LA53_;
			failedAssertImpl__systemZassertions_56(((NimStringDesc*) &TM__9aNn2jEg4ezQBM0yZx8s2cA_13));
		}
		LA53_: ;
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tySequence__7Ph69cTgZS9be09cTzR9afiJeA*, constructCfg__dfa_1143)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* body) {
	tySequence__7Ph69cTgZS9be09cTzR9afiJeA* result;
	tyObject_Con__9bOyOsCU76VZVizp72T2TsQ c;
	NI oldLenX60gensym133_;
	NI T1_;
	tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ T2_;
	NI T3_;
	result = NIM_NIL;
	nimZeroMem((void*)(&c), sizeof(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ));
	nimZeroMem((void*)(&c), sizeof(tyObject_Con__9bOyOsCU76VZVizp72T2TsQ));
	c.code = NIM_NIL;
	c.blocks = NIM_NIL;
	c.owner = s;
	T1_ = (c.blocks ? c.blocks->Sup.len : 0);
	oldLenX60gensym133_ = T1_;
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ));
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ));
	T2_.isTryBlock = NIM_FALSE;
	T2_._isTryBlock_1.label = s;
	c.blocks = (tySequence__z8L8BvgPZ9bdGD1gr7FvhEw*) incrSeqV3((TGenericSeq*)(c.blocks), (&NTIseqLtblockT__z8L8BvgPZ9bdGD1gr7FvhEw_));
	T3_ = c.blocks->Sup.len++;
	genericAssign((void*)(&c.blocks->data[T3_]), (void*)(&T2_), (&NTItblock__fDjXGXL6cUaNFnT0rMSIiQ_));
	gen__dfa_200((&c), body);
	genImplicitReturn__dfa_774((&c));
	popBlock__dfa_203((&c), oldLenX60gensym133_);
	result = c.code;
	return result;
}
static N_INLINE(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**, X5BX5D___ast_4837)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** s, NI sLen_0, NI i) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** result;
	result = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
	result = &s[(NI)(sLen_0 - i)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w, aliases__dfa_808)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* obj, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* field) {
	tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w result;
	tySequence__IeU9azYSNIK3V9b36Ir6NZcw* objImportantNodes;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* obj_2;
	tySequence__IeU9azYSNIK3V9b36Ir6NZcw* fieldImportantNodes;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* field_2;
{	result = (tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w)0;
	objImportantNodes = NIM_NIL;
	obj_2 = obj;
	{
		while (1) {
			switch ((*obj_2).kind) {
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
			{
				obj_2 = (*obj_2)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
			{
				obj_2 = (*obj_2)._kind_6.sons->data[((NI) 1)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
			{
				NI T6_;
				objImportantNodes = (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) incrSeqV3((TGenericSeq*)(objImportantNodes), (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_));
				T6_ = objImportantNodes->Sup.len++;
				asgnRef((void**) (&objImportantNodes->data[T6_]), obj_2);
				obj_2 = (*obj_2)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
			{
				NI T8_;
				objImportantNodes = (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) incrSeqV3((TGenericSeq*)(objImportantNodes), (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_));
				T8_ = objImportantNodes->Sup.len++;
				asgnRef((void**) (&objImportantNodes->data[T8_]), obj_2);
				goto LA1;
			}
			break;
			default:
			{
				result = ((tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w) 1);
				goto BeforeRet_;
			}
			break;
			}
		}
	} LA1: ;
	fieldImportantNodes = NIM_NIL;
	field_2 = field;
	{
		while (1) {
			switch ((*field_2).kind) {
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
			{
				field_2 = (*field_2)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
			{
				field_2 = (*field_2)._kind_6.sons->data[((NI) 1)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
			{
				NI T15_;
				fieldImportantNodes = (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) incrSeqV3((TGenericSeq*)(fieldImportantNodes), (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_));
				T15_ = fieldImportantNodes->Sup.len++;
				asgnRef((void**) (&fieldImportantNodes->data[T15_]), field_2);
				field_2 = (*field_2)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
			{
				NI T17_;
				fieldImportantNodes = (tySequence__IeU9azYSNIK3V9b36Ir6NZcw*) incrSeqV3((TGenericSeq*)(fieldImportantNodes), (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_));
				T17_ = fieldImportantNodes->Sup.len++;
				asgnRef((void**) (&fieldImportantNodes->data[T17_]), field_2);
				goto LA10;
			}
			break;
			default:
			{
				result = ((tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w) 1);
				goto BeforeRet_;
			}
			break;
			}
		}
	} LA10: ;
	{
		NI T21_;
		NI T22_;
		T21_ = (fieldImportantNodes ? fieldImportantNodes->Sup.len : 0);
		T22_ = (objImportantNodes ? objImportantNodes->Sup.len : 0);
		if (!(T21_ < T22_)) goto LA23_;
		result = ((tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w) 1);
		goto BeforeRet_;
	}
	LA23_: ;
	result = ((tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w) 0);
	{
		NI i;
		NI colontmp_;
		NI T26_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T26_ = (objImportantNodes ? objImportantNodes->Sup.len : 0);
		colontmp_ = T26_;
		res = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* currFieldPath;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** T29_;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* currObjPath;
				tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw** T30_;
				if (!(res <= colontmp_)) goto LA28;
				i = res;
				T29_ = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
				T29_ = X5BX5D___ast_4837((fieldImportantNodes) ? (fieldImportantNodes->data) : NIM_NIL, (fieldImportantNodes ? fieldImportantNodes->Sup.len : 0), i);
				currFieldPath = (*T29_);
				T30_ = (tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw**)0;
				T30_ = X5BX5D___ast_4837((objImportantNodes) ? (objImportantNodes->data) : NIM_NIL, (objImportantNodes ? objImportantNodes->Sup.len : 0), i);
				currObjPath = (*T30_);
				{
					if (!!(((*currFieldPath).kind == (*currObjPath).kind))) goto LA33_;
					result = ((tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w) 1);
					goto BeforeRet_;
				}
				LA33_: ;
				switch ((*currFieldPath).kind) {
				case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
				{
					{
						if (!!(((*currFieldPath)._kind_4.sym == (*currObjPath)._kind_4.sym))) goto LA38_;
						result = ((tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w) 1);
						goto BeforeRet_;
					}
					LA38_: ;
				}
				break;
				case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45):
				{
					{
						if (!!(((*(*currFieldPath)._kind_6.sons->data[((NI) 1)])._kind_4.sym == (*(*currObjPath)._kind_6.sons->data[((NI) 1)])._kind_4.sym))) goto LA43_;
						result = ((tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w) 1);
						goto BeforeRet_;
					}
					LA43_: ;
				}
				break;
				case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
				{
					{
						NIM_BOOL T48_;
						T48_ = (NIM_BOOL)0;
						T48_ = ((*(*currFieldPath)._kind_6.sons->data[((NI) 1)]).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) && (*(*currFieldPath)._kind_6.sons->data[((NI) 1)]).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22));
						if (!(T48_)) goto LA49_;
						T48_ = ((*(*currObjPath)._kind_6.sons->data[((NI) 1)]).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) && (*(*currObjPath)._kind_6.sons->data[((NI) 1)]).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22));
						LA49_: ;
						if (!T48_) goto LA50_;
						{
							if (!!(((*(*currFieldPath)._kind_6.sons->data[((NI) 1)])._kind_1.intVal == (*(*currObjPath)._kind_6.sons->data[((NI) 1)])._kind_1.intVal))) goto LA54_;
							result = ((tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w) 1);
							goto BeforeRet_;
						}
						LA54_: ;
					}
					goto LA46_;
					LA50_: ;
					{
						result = ((tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w) 2);
					}
					LA46_: ;
				}
				break;
				default:
				{
				}
				break;
				}
				res += ((NI) 1);
			} LA28: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isSinkParam__ast_5042)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*s).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3));
	if (!(T1_)) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*(*s).typ).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 46));
	if (T3_) goto LA4_;
	T3_ = (((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) 4))&63U)))!=0);
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isAnalysableFieldAccess__dfa_911)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* orig, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner) {
	NIM_BOOL result;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
	NIM_BOOL T12_;
	NIM_BOOL T13_;
	NIM_BOOL T14_;
	NIM_BOOL T18_;
{	result = (NIM_BOOL)0;
	n = orig;
	{
		while (1) {
			switch ((*n).kind) {
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 42):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
			{
				n = (*n)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
			{
				n = (*n)._kind_6.sons->data[((NI) 1)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 65):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 47):
			{
				NIM_BOOL T6_;
				NIM_BOOL T7_;
				tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* T10_;
				n = (*n)._kind_6.sons->data[((NI) 0)];
				T6_ = (NIM_BOOL)0;
				T7_ = (NIM_BOOL)0;
				T7_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
				if (!(T7_)) goto LA8_;
				T7_ = ((*(*n)._kind_4.sym).owner == owner);
				LA8_: ;
				T6_ = T7_;
				if (!(T6_)) goto LA9_;
				T10_ = NIM_NIL;
				T10_ = skipTypes__ast_3723((*(*n)._kind_4.sym).typ, TM__9aNn2jEg4ezQBM0yZx8s2cA_17);
				T6_ = ((*T10_).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 45));
				LA9_: ;
				result = T6_;
				goto BeforeRet_;
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	T12_ = (NIM_BOOL)0;
	T13_ = (NIM_BOOL)0;
	T14_ = (NIM_BOOL)0;
	T14_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
	if (!(T14_)) goto LA15_;
	T14_ = ((*(*n)._kind_4.sym).owner == owner);
	LA15_: ;
	T13_ = T14_;
	if (!(T13_)) goto LA16_;
	T13_ = ((IL64(2199090364424) & (*(*n)._kind_4.sym).flags) == 0);
	LA16_: ;
	T12_ = T13_;
	if (!(T12_)) goto LA17_;
	T18_ = (NIM_BOOL)0;
	T18_ = !(((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 3)));
	if (T18_) goto LA19_;
	T18_ = isSinkParam__ast_5042((*n)._kind_4.sym);
	LA19_: ;
	T12_ = T18_;
	LA17_: ;
	result = T12_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipConvDfa__dfa_796)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = n;
	{
		while (1) {
			switch ((*result).kind) {
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
			{
				result = (*result)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
			{
				result = (*result)._kind_6.sons->data[((NI) 1)];
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmdfadotnim_DatInit000)(void) {
static TNimNode* TM__9aNn2jEg4ezQBM0yZx8s2cA_2_2[2];
static TNimNode* TM__9aNn2jEg4ezQBM0yZx8s2cA_3_2[2];
static TNimNode* TM__9aNn2jEg4ezQBM0yZx8s2cA_4_2[2];
static TNimNode* TM__9aNn2jEg4ezQBM0yZx8s2cA_5_2[2];
static TNimNode* TM__9aNn2jEg4ezQBM0yZx8s2cA_6_4[4];
NI TM__9aNn2jEg4ezQBM0yZx8s2cA_8;
static char* NIM_CONST TM__9aNn2jEg4ezQBM0yZx8s2cA_7[4] = {
"goto", 
"fork", 
"def", 
"use"};
static TNimNode* TM__9aNn2jEg4ezQBM0yZx8s2cA_14_3[3];
NI TM__9aNn2jEg4ezQBM0yZx8s2cA_16;
static char* NIM_CONST TM__9aNn2jEg4ezQBM0yZx8s2cA_15[3] = {
"yes", 
"no", 
"maybe"};
static TNimNode TM__9aNn2jEg4ezQBM0yZx8s2cA_0[24];
NTItblock__fDjXGXL6cUaNFnT0rMSIiQ_.size = sizeof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ);
NTItblock__fDjXGXL6cUaNFnT0rMSIiQ_.align = NIM_ALIGNOF(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ);
NTItblock__fDjXGXL6cUaNFnT0rMSIiQ_.kind = 18;
NTItblock__fDjXGXL6cUaNFnT0rMSIiQ_.base = 0;
NTItblock__fDjXGXL6cUaNFnT0rMSIiQ_.flags = 2;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[0].kind = 3;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[0].offset = offsetof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ, isTryBlock);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[0].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[0].name = "isTryBlock";
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[0].sons = &NimDT___fDjXGXL6cUaNFnT0rMSIiQ_isTryBlock[0];
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[0].len = 2;
TM__9aNn2jEg4ezQBM0yZx8s2cA_2_2[0] = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[2];
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[2].kind = 1;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[2].offset = offsetof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ, _isTryBlock_1.label);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[2].typ = (&NTIpsym__u9bhQvrOYyAS9bCQ6gt41GOQ_);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[2].name = "label";
TM__9aNn2jEg4ezQBM0yZx8s2cA_2_2[1] = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[3];
NTILtposition_seqLpnodeTT__HQcnEvwXwW8nB4mw1aSc9bg_.size = sizeof(tyTuple__HQcnEvwXwW8nB4mw1aSc9bg);
NTILtposition_seqLpnodeTT__HQcnEvwXwW8nB4mw1aSc9bg_.align = NIM_ALIGNOF(tyTuple__HQcnEvwXwW8nB4mw1aSc9bg);
NTILtposition_seqLpnodeTT__HQcnEvwXwW8nB4mw1aSc9bg_.kind = 18;
NTILtposition_seqLpnodeTT__HQcnEvwXwW8nB4mw1aSc9bg_.base = 0;
NTILtposition_seqLpnodeTT__HQcnEvwXwW8nB4mw1aSc9bg_.flags = 2;
TM__9aNn2jEg4ezQBM0yZx8s2cA_3_2[0] = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[5];
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[5].kind = 1;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[5].offset = offsetof(tyTuple__HQcnEvwXwW8nB4mw1aSc9bg, Field0);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[5].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[5].name = "Field0";
TM__9aNn2jEg4ezQBM0yZx8s2cA_3_2[1] = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[6];
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[6].kind = 1;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[6].offset = offsetof(tyTuple__HQcnEvwXwW8nB4mw1aSc9bg, Field1);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[6].typ = (&NTItnodeseq__IeU9azYSNIK3V9b36Ir6NZcw_);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[6].name = "Field1";
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[4].len = 2; TM__9aNn2jEg4ezQBM0yZx8s2cA_0[4].kind = 2; TM__9aNn2jEg4ezQBM0yZx8s2cA_0[4].sons = &TM__9aNn2jEg4ezQBM0yZx8s2cA_3_2[0];
NTILtposition_seqLpnodeTT__HQcnEvwXwW8nB4mw1aSc9bg_.node = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[4];
NTIseqLLtposition_seqLpnodeTTT__AO6tQ23B9aS9b43hhtsROhdQ_.size = sizeof(tySequence__AO6tQ23B9aS9b43hhtsROhdQ*);
NTIseqLLtposition_seqLpnodeTTT__AO6tQ23B9aS9b43hhtsROhdQ_.align = NIM_ALIGNOF(tySequence__AO6tQ23B9aS9b43hhtsROhdQ*);
NTIseqLLtposition_seqLpnodeTTT__AO6tQ23B9aS9b43hhtsROhdQ_.kind = 24;
NTIseqLLtposition_seqLpnodeTTT__AO6tQ23B9aS9b43hhtsROhdQ_.base = (&NTILtposition_seqLpnodeTT__HQcnEvwXwW8nB4mw1aSc9bg_);
NTIseqLLtposition_seqLpnodeTTT__AO6tQ23B9aS9b43hhtsROhdQ_.flags = 2;
NTIseqLLtposition_seqLpnodeTTT__AO6tQ23B9aS9b43hhtsROhdQ_.marker = Marker_tySequence__AO6tQ23B9aS9b43hhtsROhdQ;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[3].kind = 1;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[3].offset = offsetof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ, _isTryBlock_1.breakFixups);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[3].typ = (&NTIseqLLtposition_seqLpnodeTTT__AO6tQ23B9aS9b43hhtsROhdQ_);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[3].name = "breakFixups";
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[1].len = 2; TM__9aNn2jEg4ezQBM0yZx8s2cA_0[1].kind = 2; TM__9aNn2jEg4ezQBM0yZx8s2cA_0[1].sons = &TM__9aNn2jEg4ezQBM0yZx8s2cA_2_2[0];
NimDT___fDjXGXL6cUaNFnT0rMSIiQ_isTryBlock[0] = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[1];
TM__9aNn2jEg4ezQBM0yZx8s2cA_4_2[0] = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[8];
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[8].kind = 1;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[8].offset = offsetof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ, _isTryBlock_2.finale);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[8].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[8].name = "finale";
TM__9aNn2jEg4ezQBM0yZx8s2cA_4_2[1] = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[9];
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[9].kind = 1;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[9].offset = offsetof(tyObject_TBlock__fDjXGXL6cUaNFnT0rMSIiQ, _isTryBlock_2.raiseFixups);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[9].typ = (&NTIseqLtpositionT__qwqHTkRvwhrRyENtudHQ7g_);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[9].name = "raiseFixups";
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[7].len = 2; TM__9aNn2jEg4ezQBM0yZx8s2cA_0[7].kind = 2; TM__9aNn2jEg4ezQBM0yZx8s2cA_0[7].sons = &TM__9aNn2jEg4ezQBM0yZx8s2cA_4_2[0];
NimDT___fDjXGXL6cUaNFnT0rMSIiQ_isTryBlock[1] = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[7];
NTItblock__fDjXGXL6cUaNFnT0rMSIiQ_.node = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[0];
NTIseqLtblockT__z8L8BvgPZ9bdGD1gr7FvhEw_.size = sizeof(tySequence__z8L8BvgPZ9bdGD1gr7FvhEw*);
NTIseqLtblockT__z8L8BvgPZ9bdGD1gr7FvhEw_.align = NIM_ALIGNOF(tySequence__z8L8BvgPZ9bdGD1gr7FvhEw*);
NTIseqLtblockT__z8L8BvgPZ9bdGD1gr7FvhEw_.kind = 24;
NTIseqLtblockT__z8L8BvgPZ9bdGD1gr7FvhEw_.base = (&NTItblock__fDjXGXL6cUaNFnT0rMSIiQ_);
NTIseqLtblockT__z8L8BvgPZ9bdGD1gr7FvhEw_.flags = 2;
NTIseqLtblockT__z8L8BvgPZ9bdGD1gr7FvhEw_.marker = Marker_tySequence__z8L8BvgPZ9bdGD1gr7FvhEw;
NTIinstr__M1JDxfxGyVaK5N9ctM7QW2w_.size = sizeof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w);
NTIinstr__M1JDxfxGyVaK5N9ctM7QW2w_.align = NIM_ALIGNOF(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w);
NTIinstr__M1JDxfxGyVaK5N9ctM7QW2w_.kind = 18;
NTIinstr__M1JDxfxGyVaK5N9ctM7QW2w_.base = 0;
NTIinstr__M1JDxfxGyVaK5N9ctM7QW2w_.flags = 2;
TM__9aNn2jEg4ezQBM0yZx8s2cA_5_2[0] = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[11];
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[11].kind = 1;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[11].offset = offsetof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w, n);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[11].typ = (&NTIpnode__PzkjRjFZybhcKJ9c8COQy5g_);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[11].name = "n";
TM__9aNn2jEg4ezQBM0yZx8s2cA_5_2[1] = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[12];
NTIinstrkind__82Too4YSWL3lxgkmNlM6Mw_.size = sizeof(tyEnum_InstrKind__82Too4YSWL3lxgkmNlM6Mw);
NTIinstrkind__82Too4YSWL3lxgkmNlM6Mw_.align = NIM_ALIGNOF(tyEnum_InstrKind__82Too4YSWL3lxgkmNlM6Mw);
NTIinstrkind__82Too4YSWL3lxgkmNlM6Mw_.kind = 14;
NTIinstrkind__82Too4YSWL3lxgkmNlM6Mw_.base = 0;
NTIinstrkind__82Too4YSWL3lxgkmNlM6Mw_.flags = 3;
for (TM__9aNn2jEg4ezQBM0yZx8s2cA_8 = 0; TM__9aNn2jEg4ezQBM0yZx8s2cA_8 < 4; TM__9aNn2jEg4ezQBM0yZx8s2cA_8++) {
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[TM__9aNn2jEg4ezQBM0yZx8s2cA_8+13].kind = 1;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[TM__9aNn2jEg4ezQBM0yZx8s2cA_8+13].offset = TM__9aNn2jEg4ezQBM0yZx8s2cA_8;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[TM__9aNn2jEg4ezQBM0yZx8s2cA_8+13].name = TM__9aNn2jEg4ezQBM0yZx8s2cA_7[TM__9aNn2jEg4ezQBM0yZx8s2cA_8];
TM__9aNn2jEg4ezQBM0yZx8s2cA_6_4[TM__9aNn2jEg4ezQBM0yZx8s2cA_8] = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[TM__9aNn2jEg4ezQBM0yZx8s2cA_8+13];
}
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[17].len = 4; TM__9aNn2jEg4ezQBM0yZx8s2cA_0[17].kind = 2; TM__9aNn2jEg4ezQBM0yZx8s2cA_0[17].sons = &TM__9aNn2jEg4ezQBM0yZx8s2cA_6_4[0];
NTIinstrkind__82Too4YSWL3lxgkmNlM6Mw_.node = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[17];
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[12].kind = 3;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[12].offset = offsetof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w, kind);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[12].typ = (&NTIinstrkind__82Too4YSWL3lxgkmNlM6Mw_);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[12].name = "kind";
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[12].sons = &NimDT___M1JDxfxGyVaK5N9ctM7QW2w_kind[0];
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[12].len = 4;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[18].kind = 1;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[18].offset = offsetof(tyObject_Instr__M1JDxfxGyVaK5N9ctM7QW2w, dest);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[18].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[18].name = "dest";
NimDT___M1JDxfxGyVaK5N9ctM7QW2w_kind[0] = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[18];
NimDT___M1JDxfxGyVaK5N9ctM7QW2w_kind[1] = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[18];
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[19].len = 0; TM__9aNn2jEg4ezQBM0yZx8s2cA_0[19].kind = 2;
NimDT___M1JDxfxGyVaK5N9ctM7QW2w_kind[4] = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[19];
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[10].len = 2; TM__9aNn2jEg4ezQBM0yZx8s2cA_0[10].kind = 2; TM__9aNn2jEg4ezQBM0yZx8s2cA_0[10].sons = &TM__9aNn2jEg4ezQBM0yZx8s2cA_5_2[0];
NTIinstr__M1JDxfxGyVaK5N9ctM7QW2w_.node = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[10];
NTIcontrolflowgraph__7Ph69cTgZS9be09cTzR9afiJeA_.size = sizeof(tySequence__7Ph69cTgZS9be09cTzR9afiJeA*);
NTIcontrolflowgraph__7Ph69cTgZS9be09cTzR9afiJeA_.align = NIM_ALIGNOF(tySequence__7Ph69cTgZS9be09cTzR9afiJeA*);
NTIcontrolflowgraph__7Ph69cTgZS9be09cTzR9afiJeA_.kind = 24;
NTIcontrolflowgraph__7Ph69cTgZS9be09cTzR9afiJeA_.base = (&NTIinstr__M1JDxfxGyVaK5N9ctM7QW2w_);
NTIcontrolflowgraph__7Ph69cTgZS9be09cTzR9afiJeA_.flags = 2;
NTIcontrolflowgraph__7Ph69cTgZS9be09cTzR9afiJeA_.marker = Marker_tySequence__7Ph69cTgZS9be09cTzR9afiJeA;
NTIaliaskind__vyyqF5f609aD8pvRKZixr4w_.size = sizeof(tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w);
NTIaliaskind__vyyqF5f609aD8pvRKZixr4w_.align = NIM_ALIGNOF(tyEnum_AliasKind__vyyqF5f609aD8pvRKZixr4w);
NTIaliaskind__vyyqF5f609aD8pvRKZixr4w_.kind = 14;
NTIaliaskind__vyyqF5f609aD8pvRKZixr4w_.base = 0;
NTIaliaskind__vyyqF5f609aD8pvRKZixr4w_.flags = 3;
for (TM__9aNn2jEg4ezQBM0yZx8s2cA_16 = 0; TM__9aNn2jEg4ezQBM0yZx8s2cA_16 < 3; TM__9aNn2jEg4ezQBM0yZx8s2cA_16++) {
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[TM__9aNn2jEg4ezQBM0yZx8s2cA_16+20].kind = 1;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[TM__9aNn2jEg4ezQBM0yZx8s2cA_16+20].offset = TM__9aNn2jEg4ezQBM0yZx8s2cA_16;
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[TM__9aNn2jEg4ezQBM0yZx8s2cA_16+20].name = TM__9aNn2jEg4ezQBM0yZx8s2cA_15[TM__9aNn2jEg4ezQBM0yZx8s2cA_16];
TM__9aNn2jEg4ezQBM0yZx8s2cA_14_3[TM__9aNn2jEg4ezQBM0yZx8s2cA_16] = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[TM__9aNn2jEg4ezQBM0yZx8s2cA_16+20];
}
TM__9aNn2jEg4ezQBM0yZx8s2cA_0[23].len = 3; TM__9aNn2jEg4ezQBM0yZx8s2cA_0[23].kind = 2; TM__9aNn2jEg4ezQBM0yZx8s2cA_0[23].sons = &TM__9aNn2jEg4ezQBM0yZx8s2cA_14_3[0];
NTIaliaskind__vyyqF5f609aD8pvRKZixr4w_.node = &TM__9aNn2jEg4ezQBM0yZx8s2cA_0[23];
}

